Crate confidential_identity_core

Crate confidential_identity_core 

Re-exports

pub use curve25519_dalek;

Modules

asset_proofs
The asset_proofs library contains API for generating asset proofs and verifying them as part of the MERCAT project.
cdd_claim
codec_wrapper

Structs

CompressedRistretto
A Ristretto point, in compressed wire format.
RistrettoPoint
A RistrettoPoint represents a point in the Ristretto group for Curve25519. Ristretto, a variant of Decaf, constructs a prime-order group as a quotient group of a subgroup of (the Edwards form of) Curve25519.
Scalar
The Scalar struct holds an integer \(s < 2^{255} \) which represents an element of \(\mathbb Z / \ell\).