Crate confidential_identity_core
confidential_
identity_
core
1.1.2
All Items
Crate Items
Re-exports
Modules
Structs
Crate
confidential_
identity_
core
Re-exports

pub use
curve25519_dalek
;
Modules

asset_
proofs
The
asset_proofs
library contains API for generating asset proofs and verifying them as part of the MERCAT project.
cdd_
claim
codec_
wrapper
Structs

Compressed
Ristretto
A Ristretto point, in compressed wire format.
Ristretto
Point
A
RistrettoPoint
represents a point in the Ristretto group for Curve25519. Ristretto, a variant of Decaf, constructs a prime-order group as a quotient group of a subgroup of (the Edwards form of) Curve25519.
Scalar
The
Scalar
struct holds an integer \(s < 2^{255} \) which represents an element of \(\mathbb Z / \ell\).